<p align="center">
  <img src="http://tynecki.pl/phages2050-logo.png">
</p>

> "Keep calm, use AI for phages and stop AMR"

PHAGES2050 is a novel [Python 3.6+ programming language](https://python.org) framework to boost bacteriophage research & therapy and infrastructure in order to achieve the full potential to fight against antimicrobial resistant bacteria within **Natural Language Processing (NLP)** and **Deep Learning**.

Our project is about developing a AI-based framework for microbiologists and bioinformaticians who hunt, explore and classify phages. Applying the framework will shorten the duration of computational methods required to match phages with bacteria for specific patient cases. Having such organised framework at hand and freely-available will help develop personalized phage therapy and make it accessible to people worldwide.

Watch the [PHAVES #3](https://www.youtube.com/watch?v=gh_Q135t9ps) talk to learn more.

[![Build Status](https://travis-ci.org/phages2050-dev/phages2050.svg?branch=master)](https://travis-ci.org/phages2050-dev/phages2050)
[![Documentation Status](https://readthedocs.org/projects/phages2050/badge/?version=stable)](https://phages2050.readthedocs.io/en/stable/?badge=stable)
[![PyPI version](https://img.shields.io/pypi/v/phages2050.svg)](https://pypi.org/project/phages2050/)
[![PyPI license](https://img.shields.io/pypi/l/phages2050.svg)](https://pypi.python.org/pypi/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/phages2050.svg)](https://pypi.python.org/pypi/phages2050/)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Table of Contents

[Framework modules](https://github.com/ptynecki/PHAGES2050#framework-modules) | [Usage](https://github.com/ptynecki/PHAGES2050#usage) | [Expected Results](https://github.com/ptynecki/PHAGES2050#expected-results) | [Documentation](https://github.com/ptynecki/PHAGES2050#documentation) | [Installation](https://github.com/ptynecki/PHAGES2050#installation) | [Community and Contributions](https://github.com/ptynecki/PHAGES2050#community-and-contributions) | [Have a question?](https://github.com/ptynecki/PHAGES2050#have-a-question) | [Found a bug?](https://github.com/ptynecki/PHAGES2050#found-a-bug) | [Team](https://github.com/ptynecki/PHAGES2050#team) | [Change log](https://github.com/ptynecki/PHAGES2050#change-log) | [Code of Conduct](https://github.com/ptynecki/PHAGES2050#code-of-conduct) | [License](https://github.com/ptynecki/PHAGES2050#license)

## Framework modules

`crawlers` - set of functions responsible for bacteriophages data scraping from different sources (MillardLab, NCBI)  
`features` - set of functions responsible for nucleotides and proteins feature extraction for Machine Learning classification and deeper analysis  
`embeddings` - set of pre-trained Embedding models for nucleotides and proteins vectorization  
`classifiers` - set of pre-trained Machine Learning models dedicated for bacteriophage research

## Usage

## Expected Results

## Documentation

The official documentation is hosted on ReadTheDocs: https://phages2050.readthedocs.io

## Installation

_PHAGES2050_ can be installed by running:

```
pip install phages2050
```

It requires Python 3.6.0+ to run. You can also use Conda:

```
conda install -c conda-forge phages2050
```

#### Install from GitHub

If you can't wait for the latest hotness and want to install from GitHub, use:

```
pip install git+git://github.com/ptynecki/PHAGES2050
```

#### Proteins' embedding

If you want to use Bacteriophage proteins vectorizers then remember to install extra package for proteins embedding:

```
pip install -U "bio-embeddings[all] @ git+https://github.com/sacdallago/bio_embeddings.git"
```

## Community and Contributions

## Have a question?

Obviously if you have a private question or want to cooperate with us, you can always reach out to us directly via our [Phage Directory Slack](https://phage.directory/slack) (channel **#PHAGES2050**).

## Found a bug?

Feel free to add a new issue with a respective title and description on the [the PHAGES2050 repository](https://github.com/ptynecki/PHAGES2050/issues). If you already found a solution to your problem, we would be happy to review your pull request.

## Team

#### Data Science crew
![](http://tynecki.pl/phages2050-datascience-team-v2.png)

#### Phage domain expert crew
![](http://tynecki.pl/phages2050-phage-expert-team-v2.png)

## Change log

The log's will become rather long. It moved to its own file.

See [CHANGELOG.md](https://github.com/ptynecki/PHAGES2050/blob/master/CHANGELOG.md).

## Code of Conduct

## License

The PHAGES2050 package and pre-trained models are released under the under terms of [the MIT License](https://github.com/ptynecki/PHAGES2050/blob/master/LICENSE).
